@@ -90,7 +90,7 @@ func NewContainer(version string) (*Container, error) {
 				}
 
 				notebook := core.NewNotebook(path, config, core.NotebookPorts{
-					NoteIndex: sqlite.NewNoteIndex(db, logger),
+					NoteIndex: sqlite.NewNoteIndex(path, db, logger),
 					NoteContentParser: markdown.NewParser(
 						markdown.ParserOpts{
 							HashtagEnabled:      config.Format.Markdown.Hashtags,
